@@ -3,6 +3,7 @@
 //! See: https://github.com/goto-bus-stop/node-resolve
 
 use std::{
+    env::current_dir,
     fs::File,
     io::BufReader,
     path::{Component, Path, PathBuf},
@@ -14,6 +15,7 @@ use dashmap::{DashMap, DashSet};
 use normpath::BasePath;
 use once_cell::sync::Lazy;
 use path_clean::PathClean;
+use pathdiff::diff_paths;
 use serde::Deserialize;
 use swc_common::{collections::AHashMap, FileName};
 use tracing::debug;
@@ -53,6 +55,17 @@ fn find_package_root(path: &Path) -> Option<PathBuf> {
     None
 }
 
+pub fn to_absolute_path(path: &Path) -> Result<PathBuf, Error> {
+    let absolute_path = if path.is_absolute() {
+        path.to_path_buf()
+    } else {
+        current_dir()?.join(path)
+    }
+    .clean();
+
+    Ok(absolute_path)
+}
+
 pub(crate) fn is_core_module(s: &str) -> bool {
     NODE_BUILTINS.contains(&s)
 }
@@ -294,14 +307,17 @@ impl NodeModulesResolver {
         base_dir: &Path,
         target: &str,
     ) -> Result<Option<PathBuf>, Error> {
-        let mut path = Some(base_dir);
+        let absolute_path = to_absolute_path(base_dir)?;
+        let mut path = Some(&*absolute_path);
         while let Some(dir) = path {
             let node_modules = dir.join("node_modules");
             if node_modules.is_dir() {
                 let path = node_modules.join(target);
                 if let Some(result) = self
                     .resolve_as_file(&path)
-                    .or_else(|_| self.resolve_as_directory(&path))?
+                    .ok()
+                    .or_else(|| self.resolve_as_directory(&path).ok())
+                    .flatten()
                 {
                     return Ok(Some(result));
                 }
@@ -391,7 +407,12 @@ impl Resolve for NodeModulesResolver {
                         .and_then(|p| self.wrap(p))
                 } else {
                     self.resolve_node_modules(base_dir, target)
-                        .and_then(|p| self.wrap(p))
+                        .and_then(|path| {
+                            let file_path = path.context("Impossible to get the node_modules path");
+                            let current_directory = current_dir()?;
+                            let relative_path = diff_paths(file_path?, current_directory);
+                            self.wrap(relative_path)
+                        })
                 }
             }
         }
